Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(961)

Unified Diff: utils/pub/safe_http_server.dart

Issue 14251013: Rename unsubscribeOnError to cancelOnError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: utils/pub/safe_http_server.dart
diff --git a/utils/pub/safe_http_server.dart b/utils/pub/safe_http_server.dart
index 083cb938afd38d1553f0176570dc60fad9c84fff..9c793a0b02f8f8349df9e149684b714ddc61cbfe 100644
--- a/utils/pub/safe_http_server.dart
+++ b/utils/pub/safe_http_server.dart
@@ -43,7 +43,7 @@ class SafeHttpServer extends StreamView<HttpRequest> implements HttpServer {
StreamSubscription<HttpRequest> listen(void onData(HttpRequest value),
{void onError(AsyncError error), void onDone(),
- bool unsubscribeOnError: false}) {
+ bool cancelOnError: false}) {
var subscription;
subscription = super.listen((request) {
onData(new _HttpRequestWrapper(request));
@@ -55,9 +55,9 @@ class SafeHttpServer extends StreamView<HttpRequest> implements HttpServer {
if (error is SocketIOException && error.osError.errorCode == 104) return;
// Ignore any parsing errors, which come from malformed requests.
if (error is HttpParserException) return;
// Manually handle unsubscribeOnError so the above (ignored) errors don't
// cause unsubscription.
- if (unsubscribeOnError) subscription.cancel();
+ if (cancelOnError) subscription.cancel();
if (onError != null) onError(e);
}, onDone: onDone);
return subscription;
@@ -55,9 +55,9 @@ class SafeHttpServer extends StreamView<HttpRequest> implements HttpServer {
// Ignore any parsing errors, which come from malformed requests.
if (error is HttpParserException) return;
- // Manually handle unsubscribeOnError so the above (ignored) errors don't
+ // Manually handle cancelOnError so the above (ignored) errors don't
// cause unsubscription.
« sdk/lib/async/stream.dart ('K') | « utils/pub/io.dart ('k') | utils/pub/utils.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698